@@ -3,6 +3,8 @@
 
    Copyright (C) 2010,2011 Javier Palacios
 
+   SPDX-License-Identifier: GPL-2.0-or-later
+
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2, or (at
@@ -29,9 +31,6 @@ typedef struct {
     int size;
 } cksum_t;
 
-int cksum_init(cksum_t * cksum, char **itemlist);
-void cksum_deinit(cksum_t * cksum);
-
 typedef struct void_list_elt cksum_list_elt_t;
 
 typedef struct void_list cksum_list_t;
