@@ -94,13 +94,6 @@ static opkg_option_t options[] = {
     {"gpg_dir", OPKG_OPT_TYPE_STRING, &_conf.gpg_dir},
     {"gpg_trust_level", OPKG_OPT_TYPE_STRING, &_conf.gpg_trust_level},
 #endif
-#if defined(HAVE_OPENSSL)
-    {"signature_ca_file", OPKG_OPT_TYPE_STRING, &_conf.signature_ca_file},
-    {"signature_ca_path", OPKG_OPT_TYPE_STRING, &_conf.signature_ca_path},
-#endif
-#if defined(HAVE_PATHFINDER)
-    {"check_x509_path", OPKG_OPT_TYPE_BOOL, &_conf.check_x509_path},
-#endif
 #if defined(HAVE_CURL)
     {"connect_timeout_ms", OPKG_OPT_TYPE_INT, &_conf.connect_timeout_ms},
     {"transfer_timeout_ms", OPKG_OPT_TYPE_INT, &_conf.transfer_timeout_ms},
@@ -685,9 +678,6 @@ int opkg_conf_load(void)
 
     opkg_config->restrict_to_default_dest = 0;
     opkg_config->default_dest = NULL;
-#if defined(HAVE_PATHFINDER)
-    opkg_config->check_x509_path = 1;
-#endif
     if (!opkg_config->offline_root)
         opkg_config->offline_root = xstrdup(getenv("OFFLINE_ROOT"));
 
@@ -864,7 +854,8 @@ int opkg_conf_load(void)
     }
 
     if (opkg_config->volatile_cache) {
-        sprintf_alloc(&tmp, "%s/%s", opkg_config->cache_dir, "volatile");
+        sprintf_alloc(&tmp, "%s/%s.%d", opkg_config->cache_dir, "volatile",
+                      (int)getpid());
         free(opkg_config->cache_dir);
         opkg_config->cache_dir = tmp;
     }
@@ -918,7 +909,7 @@ void opkg_conf_deinit(void)
     if (opkg_config->tmp_dir)
         rm_r(opkg_config->tmp_dir);
 
-    if (opkg_config->volatile_cache)
+    if (opkg_config->volatile_cache && file_exists(opkg_config->cache_dir))
         rm_r(opkg_config->cache_dir);
 
     free(opkg_config->dest_str);
