@@ -6,6 +6,8 @@
    Copyright (C) 2001 University of Southern California
    Copyright (C) 2008 OpenMoko Inc
 
+   SPDX-License-Identifier: GPL-2.0-or-later
+
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2, or (at
@@ -119,6 +121,13 @@ static int opkg_download_internal(const char *src, const char *dest,
 {
     int ret;
 
+    if (use_cache) {
+        ret = file_mkdir_hier(opkg_config->cache_dir, 0755);
+        if (ret != 0)
+            opkg_perror(ERROR, "Creating cache dir %s failed",
+                    opkg_config->cache_dir);
+    }
+
     opkg_msg(NOTICE, "Downloading %s.\n", src);
 
     if (str_starts_with(src, "file:")) {
@@ -217,6 +226,8 @@ int opkg_download(const char *src, const char *dest_file_name,
         if (cache_location) {
             err = file_copy(cache_location, dest_file_name);
             free(cache_location);
+        } else {
+            err = -1;
         }
     } else {
         err = opkg_download_direct(src, dest_file_name, NULL, NULL);
@@ -312,7 +323,7 @@ int opkg_download_pkg_to_dir(pkg_t * pkg, const char *dir)
     char *url = NULL;
     int err = 0;
 
-    sprintf_alloc(&dest_file_name, "%s/%s", dir, pkg->filename);
+    sprintf_alloc(&dest_file_name, "%s/%s", dir, basename(pkg->filename));
 
     if (opkg_config->volatile_cache) {
         url = get_pkg_url(pkg);
