@@ -35,9 +35,6 @@
 #include "file_util.h"
 #include "xfuncs.h"
 
-#ifdef HAVE_OPENSSL
-#include "opkg_openssl.h"
-#endif
 
 /*
  * Make curl an instance variable so we don't have to instanciate it
@@ -106,40 +103,28 @@ static char *replace_token_in_str(const char *str, const char *token,
          */
         return xstrdup(str);
 
-    size_t str_len = strlen(str);
     size_t replacement_len = strlen(replacement);
-
+    size_t str_len = strlen(str);
     size_t token_len = strlen(token);
-    unsigned int token_idx = found_token - str;
 
-    size_t replaced_str_len = str_len - (strlen(token) - strlen(replacement));
-    char *replaced_str = xmalloc(replaced_str_len * sizeof(char));
+    size_t replaced_str_len = str_len - (token_len - replacement_len);
+
+    unsigned int token_idx = found_token - str;
+    char *replaced_str = xmalloc((replaced_str_len + 1) * sizeof(char));
 
     /* first copy the string part *before* the substring to replace */
-    strncpy(replaced_str, str, token_idx);
-    /* then copy the replacement at the same position than the token to replace
-     */
-    strncpy(replaced_str + token_idx, replacement, strlen(replacement));
-    /* finally complete the string with characters following the token to
-     * replace
-     */
-    strncpy(replaced_str + token_idx + replacement_len,
-            str + token_idx + token_len, strlen(str + token_idx + token_len));
+    memmove(replaced_str, str, token_idx);
+    /* then copy the replacement to the same position than the token */
+    memmove(replaced_str + token_idx, replacement, replacement_len);
+    /* finally complete the string with characters following the token */
+    memmove(replaced_str + token_idx + replacement_len,
+            str + token_idx + token_len,
+            (replaced_str_len - token_idx - replacement_len));
 
     replaced_str[replaced_str_len] = '\0';
 
     return replaced_str;
 }
-
-#if defined(HAVE_PATHFINDER) && defined(HAVE_OPENSSL)
-static CURLcode curl_ssl_ctx_function(CURL * curl, void *sslctx, void *parm)
-{
-    SSL_CTX *ctx = (SSL_CTX *) sslctx;
-    SSL_CTX_set_cert_verify_callback(ctx, pathfinder_verify_callback, parm);
-
-    return CURLE_OK;
-}
-#endif                          /* HAVE_PATHFINDER && HAVE_OPENSSL */
 #endif                          /* HAVE_SSLCURL */
 
 /** \brief create_file_stamp: creates stamp for file
@@ -376,15 +361,12 @@ void opkg_download_cleanup(void)
 
 static CURL *opkg_curl_init(curl_progress_func cb, void *data)
 {
-    int r;
-
     if (curl == NULL) {
         curl = curl_easy_init();
 
 #ifdef HAVE_SSLCURL
-#ifdef HAVE_OPENSSL
-        openssl_init();
-#endif                          /* HAVE_OPENSSL */
+
+        int r;
 
         if (opkg_config->ssl_engine) {
             /* use crypto engine */
@@ -432,12 +414,6 @@ static CURL *opkg_curl_init(curl_progress_func cb, void *data)
              * CURLOPT_SSL_VERIFYPEER default is nonzero (curl => 7.10)
              */
             setopt(CURLOPT_SSL_VERIFYPEER, 0);
-#if defined(HAVE_PATHFINDER) && defined(HAVE_OPENSSL)
-        else if (opkg_config->check_x509_path) {
-                setopt(CURLOPT_SSL_CTX_FUNCTION, curl_ssl_ctx_function);
-                setopt(CURLOPT_SSL_CTX_DATA, NULL);
-        }
-#endif
 
         /* certification authority file and/or path */
         if (opkg_config->ssl_ca_file)
