@@ -5,6 +5,8 @@
 
    Copyright (C) 2002 Compaq Computer Corporation
 
+   SPDX-License-Identifier: GPL-2.0-or-later
+
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2, or (at
@@ -182,8 +184,12 @@ static int dist_hash_add_from_file(pkg_src_t * dist)
                 free(list_file);
                 return -1;
             }
+            char *subpath, *distribution, *component;
+            distribution = strtok(dist->name, "-");
+            component = strtok(NULL, "-");
+            sprintf_alloc(&subpath, "dists/%s/%s/binary-%s", distribution, component, nv->name);
             pkg_src_list_append(&opkg_config->pkg_src_list, subname,
-                                dist->value, NULL, "__dummy__", 0);
+                                dist->value, NULL, subpath, 0);
         }
 
         free(list_file);
