@@ -3,6 +3,8 @@
 
    Copyright (C) 2016 National Instruments Corporation
 
+   SPDX-License-Identifier: GPL-2.0-or-later
+
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2, or (at
@@ -228,7 +230,8 @@ int pkg_hash_fetch_unsatisfied_dependencies(pkg_t *pkg,
                             || compound_depend->type == SUGGEST)
                         && (satisfying_pkg->state_want == SW_DEINSTALL
                             || satisfying_pkg->state_want == SW_PURGE
-                            || opkg_config->no_install_recommends);
+                            || opkg_config->no_install_recommends
+                            || str_list_contains(&opkg_config->ignore_recommends_list, satisfying_pkg->name, 1));
                 if (ignore) {
                     opkg_msg(NOTICE,
                              "%s: ignoring recommendation for "
@@ -239,7 +242,7 @@ int pkg_hash_fetch_unsatisfied_dependencies(pkg_t *pkg,
 
                 /* Check for excluded packages */
                 int exclude = str_list_contains(&opkg_config->exclude_list,
-                                         satisfying_pkg->name);
+                                         satisfying_pkg->name, 1);
                 if (exclude) {
                     opkg_msg(NOTICE,
                              "%s: exclude required package %s at users request\n",
