@@ -567,10 +567,6 @@ static void populate_available_repos(libsolv_solver_t *libsolv_solver)
     for (i = 0; i < available_pkgs->len; i++) {
         pkg_t *pkg = available_pkgs->pkgs[i];
 
-        /* if the package is marked as excluded, skip it */
-        if (str_list_contains(&opkg_config->exclude_list, pkg->name, 1))
-            continue;
-
         /* if the package is installed or unpacked, skip it */
         if (pkg->state_status == SS_INSTALLED ||
             pkg->state_status == SS_UNPACKED ||
@@ -636,6 +632,15 @@ static void populate_available_repos(libsolv_solver_t *libsolv_solver)
                         | SOLVER_DISFAVOR, what);
         }
 
+        /* if the package is marked as excluded, blacklist it */
+        if (str_list_contains(&opkg_config->exclude_list, pkg->name, 1)) {
+            opkg_message(DEBUG2, "Blacklist package due to exclusion: %s\n",
+                         pkg->name);
+            what = pool_str2id(libsolv_solver->pool, pkg->name, 1);
+            queue_push2(&libsolv_solver->solver_jobs, SOLVER_SOLVABLE_NAME
+                        | SOLVER_BLACKLIST, what);
+        }
+
         /* if the --force-depends option is specified make dependencies weak */
         if (opkg_config->force_depends)
             queue_push2(&libsolv_solver->solver_jobs, SOLVER_SOLVABLE
@@ -645,7 +650,7 @@ static void populate_available_repos(libsolv_solver_t *libsolv_solver)
     pkg_vec_free(available_pkgs);
 }
 
-static void printsolution_callback(struct _Pool *pool, void *data, int type, const char *str)
+static void printsolution_callback(struct s_Pool *pool, void *data, int type, const char *str)
 {
     opkg_message(ERROR, "%s\n", str);
 }
