@@ -1,4 +1,5 @@
 #! /usr/bin/env python3
+# SPDX-License-Identifier: GPL-2.0-only
 #
 # Reporter: Graham Gower
 #
@@ -37,27 +38,26 @@ os.rmdir(long_dir)
 opkgcl.install("a_1.0_all.opk")
 
 if not opkgcl.is_installed("a"):
-	opk.fail("Package 'a' not installed.")
+    opk.fail("Package 'a' not installed.")
 
 if not os.path.exists("{}/{}".format(cfg.offline_root, long_dir)):
-	opk.fail("dir with name longer than 100 "
-					"characters not created.")
+    opk.fail("dir with name longer than 100 characters not created.")
 
 if not os.path.exists("{}/{}".format(cfg.offline_root, long_filename)):
-	opk.fail("file with a name longer than 100 characters, "
-				"in dir with name longer than 100 characters, "
-				"not created.")
+    opk.fail("file with a name longer than 100 characters, "
+             "in dir with name longer than 100 characters, "
+             "not created.")
 
 if not os.path.lexists("{}/{}".format(cfg.offline_root, long_filename2)):
-	opk.fail("symlink with a name longer than 100 characters, "
-				"pointing at a file with a name longer than "
-				"100 characters,"
-				"in dir with name longer than 100 characters, "
-				"not created.")
+    opk.fail("symlink with a name longer than 100 characters, "
+             "pointing at a file with a name longer than "
+             "100 characters,"
+             "in dir with name longer than 100 characters, "
+             "not created.")
 
 linky = os.path.realpath("{}/{}".format(cfg.offline_root, long_filename2))
-linky_dst = "{}/{}".format(cfg.offline_root, long_filename)
+linky_dst = os.path.realpath("{}/{}".format(cfg.offline_root, long_filename))
 if linky != linky_dst:
-	opk.fail("symlink path truncated.")
+    opk.fail("symlink path truncated.")
 
 opkgcl.remove("a")
