@@ -1,4 +1,5 @@
 #! /usr/bin/env python3
+# SPDX-License-Identifier: GPL-2.0-only
 #
 # Reporter: scot.salmon@ni.com
 #
@@ -33,8 +34,8 @@ opkgcl.update()
 
 opkgcl.install("a")
 if not opkgcl.is_installed("a"):
-	opk.fail("Package 'a' installed but reports as not installed.")
+    opk.fail("Package 'a' installed but reports as not installed.")
 
 opkgcl.install("b")
 if not opkgcl.is_installed("b"):
-        opk.xfail("Package 'b' installed but reports as not installed.")
+        opk.fail("Package 'b' installed but reports as not installed.")
